==> currents-api-types-0.0.37.tgz: package/payout/parsers.ts <==
import z from 'zod';
import { PayoutBatchItemCompositeKey, PayoutBatchKey } from './types';
import { currencyAmountParser } from '../currencies/parsers';
import { Subset } from '../utils/types';
import { PAYOUT_BATCH_ID_PARAM_NAME } from './constants';
import { nonEmptyStringParser } from '../utils/parsers';
import { payoutBatchItemCompositeKeySerializedParser } from './parsers.serialized';
import { payoutBatchItemCompositeKeyParser } from './parsers.common';
import { queryOffsetLimitParser } from '../common/parsers/queryParams';

export const payoutBatchKeyParser = nonEmptyStringParser.refine((s) => s as PayoutBatchKey);

// eslint-disable-next-line @typescript-eslint/no-unused-vars
type AssertPayoutBatchItemCompositeKeyParser1 = Subset<
  PayoutBatchItemCompositeKey,
  z.infer<typeof payoutBatchItemCompositeKeyParser>
>;
// eslint-disable-next-line @typescript-eslint/no-unused-vars
type AssertPayoutBatchItemCompositeKeyParser2 = Subset<
  z.infer<typeof payoutBatchItemCompositeKeyParser>,
  PayoutBatchItemCompositeKey
>;

export const payoutAmountParser = currencyAmountParser;
export const payoutParamsParser = z.object({
  [PAYOUT_BATCH_ID_PARAM_NAME]: payoutBatchKeyParser,
});

export const withDryParser = z.object({
  dry: z.boolean().optional().default(true),
});

export const payoutBatchItemsParser = z.record(payoutBatchItemCompositeKeySerializedParser, payoutAmountParser);

export const payoutBodyParser = z
  .object({
    items: payoutBatchItemsParser,
  })
  .merge(withDryParser);

export const payoutRetryBodyParser = z.object({}).merge(withDryParser);

export const payoutResultParser = z.object({
  successes: z.array(payoutBatchItemCompositeKeySerializedParser),
  failures: z.record(payoutBatchItemCompositeKeySerializedParser, z.string()),
});

const payoutQueueItemStatusParser = z.object({
  all: payoutBatchItemsParser,
  left: payoutBatchItemsParser,
});

export const payoutStatusResultParser = payoutQueueItemStatusParser;

export const payoutQueueQueryParser = z
  .object({
    status: z.enum(['all', 'pending'] as const),
  })
  .and(queryOffsetLimitParser);

export const payoutQueueResultParser = z.object({
  items: z.array(
    z.object({
      status: payoutQueueItemStatusParser,
      key: payoutBatchKeyParser,
    })
  ),
});

==> currents-api-types-0.0.42.tgz: package/payout/parsers.ts <==
import z from 'zod';
import { PayoutBatchItemCompositeKey, PayoutBatchKey } from './types';
import { currencyAmountParser } from '../currencies/parsers';
import { Subset } from '../utils/types';
import { PAYOUT_BATCH_ID_PARAM_NAME, PAYOUT_QUEUE_STATUSES } from './constants';
import { nonEmptyStringParser } from '../utils/parsers';
import { payoutBatchItemCompositeKeySerializedParser } from './parsers.serialized';
import { payoutBatchItemCompositeKeyParser } from './parsers.common';
import { queryOffsetLimitParser } from '../common/parsers/queryParams';
import { timestampParser } from '../parsers';

export const payoutBatchKeyParser = nonEmptyStringParser.refine((s) => s as PayoutBatchKey);

// eslint-disable-next-line @typescript-eslint/no-unused-vars
type AssertPayoutBatchItemCompositeKeyParser1 = Subset<
  PayoutBatchItemCompositeKey,
  z.infer<typeof payoutBatchItemCompositeKeyParser>
>;
// eslint-disable-next-line @typescript-eslint/no-unused-vars
type AssertPayoutBatchItemCompositeKeyParser2 = Subset<
  z.infer<typeof payoutBatchItemCompositeKeyParser>,
  PayoutBatchItemCompositeKey
>;

export const payoutAmountParser = currencyAmountParser;
export const payoutParamsParser = z.object({
  [PAYOUT_BATCH_ID_PARAM_NAME]: payoutBatchKeyParser,
});

export const withDryParser = z.object({
  dry: z.boolean().optional().default(true),
});

export const payoutBatchItemsParser = z.record(payoutBatchItemCompositeKeySerializedParser, payoutAmountParser);

export const payoutBodyParser = z
  .object({
    items: payoutBatchItemsParser,
  })
  .merge(withDryParser);

export const payoutRetryBodyParser = z.object({}).merge(withDryParser);

export const payoutResultParser = z.object({
  successes: z.array(payoutBatchItemCompositeKeySerializedParser),
  failures: z.record(payoutBatchItemCompositeKeySerializedParser, z.string()),
});

const payoutQueueItemStatusParser = z.object({
  all: payoutBatchItemsParser,
  left: payoutBatchItemsParser,
});

export const payoutStatusResultParser = payoutQueueItemStatusParser;

export const payoutQueueQueryParser = z
  .object({
    status: z.enum(PAYOUT_QUEUE_STATUSES),
  })
  .and(queryOffsetLimitParser);

export const payoutQueueResultParser = z.object({
  items: z.array(
    z.object({
      status: payoutQueueItemStatusParser,
      key: payoutBatchKeyParser,
      createdAt: timestampParser,
      updatedAt: timestampParser,
    })
  ),
});
